@@ -1,5 +1,7 @@
-from .connections import RedisSettings, create_pool, create_pool_dsn
-from .queue import Queue
 from .base import JobStoreSpec
+from .connections import RedisSettings, create_pool, create_pool_dsn
+from .job_store import RedisJobStore
+from .queue import Queue
+from .scheduler import Scheduler
 
 # from .jobs import Job
